ansible-modules-core
====================

This repo contains Ansible's most popular modules that are shipped with Ansible.

New module submissions for modules that do not yet exist should be submitted to ansible-modules-extras, rather than this repo.

Take care to submit tickets to the appropriate repo where modules are contained.  The docs.ansible.com website indicates this at the bottom of each module documentation page.

Reporting bugs
==============

Take care to submit tickets to the appropriate repo where modules are contained. The repo is mentioned at the bottom of module documentation page at [docs.ansible.com](http://docs.ansible.com/).

Testing modules
===============

Ansible [module development guide](http://docs.ansible.com/developing_modules.html#testing-modules) contains the latest info about that.

License
=======

As with Ansible, modules distributed with Ansible are GPLv3 licensed. User generated modules not part of this project can be of any license.

Installation
============

There should be no need to install this repo separately as it should be included in any Ansible install using the official documented methods.
